@@ -101,7 +101,6 @@ static void CountThreshCol(PICTURE *bild, int col, int testcols,
 
   step = storepix*(step - testcols); 
        /* bild->storepix*testcols byte will be handled in inner loop! */
-   
   for ( fip = (ip = nthresh) + testcols, jp = nterr; 
         ip < fip; ip++, jp++ ) 
     *ip = *jp = 0;
@@ -260,7 +259,7 @@ static int NewBorder(PICTURE *bild, int oldwd, int neuwd, int *left, int *right,
    nthl = g_new0(int, (delta+2) << 2 );
    nter = (nthr = (ntel = nthl + delta) + delta) + delta;
    
-   if ( (zw = *left - (delta/2) ) < 0 ) {
+   if ( (zw = *left - (delta/2) ) < delta/2 ) {
       zw = delta/2 + 1;
       al = nthl + *left;
       el = ntel + *left;
@@ -355,7 +354,7 @@ static int GetBorder(PICTURE *bild, int *left, int *right, unsigned char thresh,
  * --- Return: ---
  * int      *left       : linke Grenze
  * int      *right      : rechte Grenze
- * int      GetBorder() : RET_OK or RET_OK
+ * int      GetBorder() : RET_OK or RET_ERR
  */
 {
    register unsigned char *ap, *fip;
@@ -640,11 +639,15 @@ int SelectPictureWithoutBorder(PAUL *p)
   for ( bild = BILD(pl = piclist), i = 0; pl; bild = BILD(pl = pl->next), i++ ) {
     /* delete border left and right */
     if ( *(testlr+i) ) continue;
-    if ( *(wd+i) != neuwd ) {
+    if ( *(wd+i) > neuwd ) {
       if ( NewBorder(bild, bild->W, neuwd, lb+i, rb+i, p->opt->thresh, p->opt->terr, CountThreshCol) ) {
         g_warning(_("Width of %s can't be changed to %i."), bild->file, neuwd);
+        *(testlr+i) = -1;  /* mark as unchanged in left-right direction */
         continue; 
       }
+    } else {
+      *(testlr+i) = -1;  /* mark as unchanged in left-right direction */
+      continue;
     }
 
     *(wd+i) = neuwd;  /* WITHOUT CHECKLINE!!!! */
@@ -668,8 +671,12 @@ int SelectPictureWithoutBorder(PAUL *p)
       neuht = MIN(neuht, bild->H);
       if ( *(testtb+i) && (neuht < bild->H) && NBILDER(piclist) > 1 ) {
         g_warning(_("No change of height for all images because %s can't be cut vertically."), bild->file);
+        *(testtb+i) = -1;  /* mark as unchanged in top-bottom direction */
         neuht = 0;
         break;
+      } else {
+        *(testtb+i) = -1;  /* mark as unchanged in left-right direction */
+        continue;
       }
     }
 
@@ -678,6 +685,7 @@ int SelectPictureWithoutBorder(PAUL *p)
         if ( *(wd+i) != neuht ) {
           if ( NewBorder(bild, bild->H, neuht, tb+i, bb+i, p->opt->thresh, p->opt->terr, CountThreshRow) ) {
             g_warning(_("Height of %s can't be changed to %i."), bild->file, neuht);
+            *(testtb+i) = -1;  /* mark as unchanged in top-bottom direction */
             continue; 
           }
         }
@@ -691,7 +699,8 @@ int SelectPictureWithoutBorder(PAUL *p)
 
   /* set spezification chunks in the end */
   for ( bild = BILD(pl = piclist), i = 0; pl; bild = BILD(pl = pl->next), i++ ) {
-    if ( *(testlr+i) && !neuht ) {   /* unterschiedliche Testbedingungen ... mal sehn, ob das gut ist*/
+    if ( (*(testlr+i) && !neuht) || (*(testlr+i) && *(testtb+i)) ) {
+      /* unterschiedliche Testbedingungen ... mal sehn, ob das gut ist*/
       g_warning(_("%s remains unchanged."), bild->file);
       continue;
     }
