@@ -30,6 +30,7 @@ static void FileLoadOk(GtkWidget *widget, GtkFileSelection *fs)
   PAUL      *p;
   PICTURE   *bild;
   char      *filename;
+  GList     *pl;
 
   g_return_if_fail ( GTK_IS_FILE_SELECTION(fs) );
   g_return_if_fail ( (p = gtk_object_get_user_data(GTK_OBJECT(fs)) ) );
@@ -43,14 +44,15 @@ static void FileLoadOk(GtkWidget *widget, GtkFileSelection *fs)
   
   filename = ChdirToLoadDir(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
 
-  bild = ReadPic(filename, p->opt);
+  pl = ReadPic(filename, p->opt);
   gtk_widget_destroy(GTK_WIDGET(fs));
-  if ( !bild ) {
+  if ( !pl ) {
     FileLoad(p);
     return;
   }
    
-  AddImageToFilelist(p, bild);
+  for ( bild = BILD(pl); pl; bild = BILD(pl = pl->next) )
+    AddImageToFilelist(p, bild);
 }
 
 static void FileSaveOk(GtkWidget *widget, GtkFileSelection *fs)
@@ -176,6 +178,7 @@ static void FirstPictureLoaded(GtkWidget *widget, GtkFileSelection *fs)
   PAUL      *p;
   PICTURE   *bild;
   char      *filename;
+  GList     *pl;
 
   g_return_if_fail ( widget );
   g_return_if_fail ( GTK_IS_WIDGET(widget) );
@@ -188,14 +191,15 @@ static void FirstPictureLoaded(GtkWidget *widget, GtkFileSelection *fs)
   filename = ChdirToLoadDir(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
   g_return_if_fail ( filename ) ;
       
-  bild = ReadPic(filename, p->opt);
+  pl = ReadPic(filename, p->opt);
   gtk_widget_destroy(GTK_WIDGET(fs));
-  if ( !bild ) {
+  if ( !pl ) {
     LoadFirstPicture(p);
     return;
   }
    
-  p->piclist = g_list_append(NULL, bild);
+  for ( bild = BILD(pl); pl; bild = BILD(pl = pl->next) )
+    p->piclist = g_list_append(NULL, bild);
   CreateShowPixmaps(p->activ = p->piclist);
   GtkInterface(p);
 }
