@@ -18,6 +18,9 @@
 #include <gdk_imlib.h>
 #include <png.h>
 #include "gtkintl.h"
+#ifdef HAVE_LIBFFTW
+#include <srfftw.h>
+#endif
 
 #define  PAUL_ID      42
 #define  PICTURE_ID   17
@@ -83,7 +86,7 @@ typedef struct {
                             /* SANE (Nikon Coolscan) works with 65536 pixel per mm   	 */
    unsigned long *his;      /* histogramm                             			 */
 #ifdef HAVE_LIBFFTW
-   double        *fftprof;  /* profile of FFT                                            */
+   fftw_real     *fftprof;  /* profile of FFT                                            */
 #endif
    int            n_gamma;  /* number of elements of the gamma-table  			 */
    png_color     *gamma;    /* gamma-table                          			 */
@@ -111,7 +114,8 @@ typedef struct {
    char          *bright, /* name of textfile to output brightness                       */
                  *html,   /* name of HTML file to output                                 */
                  *link;   /* name of link to point to when clicked the inserted image    */
-   double         sek,    /* animation delay time between two images                     */
+   double         angle,  /* rotation angle                                              */
+                  sek,    /* animation delay time between two images                     */
                   scale;  /* factor for contrast                                         */
 } OPTIONS;
 
@@ -234,11 +238,14 @@ extern  const char *exename; /* "paul" ... or how to call the program */
 #define ROT_90             0x00200000
 #define ROT_180            0x00400000
 #define ROT_270            (ROT_90 | ROT_180)
-#define FFT                0x00800000
-#define HTMLOUTPUT         0x01000000
+#define ROTVAR             0x00800000
+#define FFT                0x01000000
+#define HTMLOUTPUT         0x02000000
+#define DISPLAYGRAY        0x04000000
 
 #define Differenz(flag)          ( flag & DIFFERENZ  )
 #define DoMakeGray(flag)         ( flag & MAKEGRAY )
+#define DisplayGray(flag)        ( flag & DISPLAYGRAY )
 #define DoMatchPictures(flag)    ( flag & MATCHPICTURES )
 #define DelBorder(flag)          ( flag & DELBORDER )
 #define OnlyLeftRight(flag)      ( flag & ONLYLEFTRIGHT )
@@ -264,7 +271,8 @@ extern  const char *exename; /* "paul" ... or how to call the program */
 #define Rotate90(flag)           ( (flag & ROT_90)  && !(flag & ROT_180) )
 #define Rotate180(flag)          ( (flag & ROT_180) && !(flag & ROT_90)  )
 #define Rotate270(flag)          ( flag & (ROT_90 | ROT_180) )
-#define Rotate(flag)             ( (flag & ROT_90) | (flag & ROT_180) )
+#define RotateVar(flag)          ( flag & ROTVAR )
+#define Rotate(flag)             ( (flag & ROT_90) | (flag & ROT_180) | (flag & ROTVAR) )
 #define Mirror(flag)             ( flag & (MIRROR_H | MIRROR_V) )
 #define OnlyInfo(flag)           ( !((0xFFFFFFFF&(~INFO)&(~QUIET)) & flag) && (flag&QUIET) )
 #define DoFFT(flag)              ( flag & FFT )
@@ -316,8 +324,10 @@ gint       CutArea(PICTURE *bild, BOX *cut, glong flag, gchar *was, gchar *ext,
 int        CutAreas(GList *piclist, OPTIONS *p);
 
 /* datauti.c */
+#ifdef HAVE_DATABOX 
 void       CurveWidgetDestroy(GtkWidget *window, void *data);
 GtkWidget *CreateDataboxFrame(GtkWidget *curve, char *title);
+#endif
 
 /* delbordr.c */
 int        SelectPictureWithoutBorder(PAUL *p);
@@ -348,6 +358,9 @@ void       FileSelectChanged(GtkButton *button, char **file);
 /* filter.c */
 int        FilterBilder(PAUL *p);
 
+/* gifload.c */
+GList     *PaulLoadGIF(PICTURE *bild, FILE *fp, long flag);
+
 /* gray.c */
 int        MakeGray(PAUL *p);
 void       MakeSingleGreen(PICTURE *bild, int ch);
@@ -389,7 +402,7 @@ void       NegativBuffer(unsigned char *buf, int size, int step);
 int        MakeNegative(GList *piclist);
 
 /* paulload.c */
-PICTURE   *LoadPicture(PICTURE *bild, char *file, long flag);
+GList     *LoadPicture(PICTURE *bild, char *file, long flag);
 GdkImlibImage *at_imlib_set_image_from_data(unsigned char **data, gint w, gint h);
 
 /* paulinfo.c */
@@ -445,8 +458,8 @@ char      *NewFileName(PICTURE *bild, char *appendix);
 int        NewImage(PICTURE *bild, int w_new, int h_new, unsigned char *data);
 char      *RemoveUnderscore(char *string);
 BOX       *ReadBoxFromString(char *string);
-PICTURE   *ReadPic(char *file, OPTIONS *p);
-GList     *ReadPicFiles(int nfiles, char **efiles, OPTIONS *p);
+GList     *ReadPic(char *file, OPTIONS *p);
+GList     *ReadPicFiles(GList *piclist, int nfiles, char **efiles, OPTIONS *p);
 char      *time_t2string(time_t zeit);
 
 /* pngload.c */
