@@ -429,7 +429,7 @@ char *NewFileName(PICTURE *bild, char *appendix)
   return bild->file = filename;
 }
 
-PICTURE *ReadPic(char *file, OPTIONS *opt)
+GList *ReadPic(char *file, OPTIONS *opt)
 /* Read image file of any format and initialize PICTURE structure
  * --- Parameter: ---
  * char    *file       : filename of image file
@@ -437,12 +437,15 @@ PICTURE *ReadPic(char *file, OPTIONS *opt)
  *                     : shr  : level of shrinkage
  *                     : opt == NULL for images to insert
  * --- Return: ---
- * PICTURE *ReadPic()  : new PICTURE structure containing contents of file or NULL
+ * GList *ReadPic()    : list with new PICTURE structures containing
+ *                       contents of file or NULL
  */
 {
-  PICTURE *bild;
-  char    *buf;
-  long     f;
+  PICTURE      *bild;
+  char         *buf;
+  long          f;
+  GList        *pl, *loadlist;
+  register  int flag;
    
   if ( !CheckFile(file) )  return NULL;
   g_return_val_if_fail ( (bild = InitSpec()), NULL );
@@ -450,33 +453,36 @@ PICTURE *ReadPic(char *file, OPTIONS *opt)
   if ( opt ) f = opt->f;
   else       f = 0;
   
-  if ( (LoadPicture(bild, file, f)) == NULL ) {
+  if ( (loadlist = LoadPicture(bild, file, f)) == NULL ) {
     g_warning(_("Unable to load %s."), file);
     return NULL;
   }
-  printf("%s\n", buf = ImgFileName(bild));
-  FREE(buf);
-  bild->im       = NULL;
-  if ( !opt ) return bild ;  /* images to insert doesn't need this stuff */
+  for ( bild = BILD(pl = loadlist), flag = 0; pl; bild = BILD(pl = pl->next), flag++ ) {
+    printf("%s\n", buf = ImgFileName(bild));
+    FREE(buf);
+    bild->im       = NULL;
+    if ( !opt && !flag ) continue;  /* images to insert doesn't need this stuff */
   
-  if ( IsAnimation(opt) ) bild->mark |= SEL;
+    if ( IsAnimation(opt) ) bild->mark |= SEL;
 #ifdef PHYSICAL_PAUL
-  if ( (buf = GetCharSpec(bild->spec, ChunkPhysicalDataFile)) ) {
-    LoadPhysicalParameters(buf);
-  }
-#endif
-  if ( OnlyInfo(opt->f) ) return bild;
-  if ( bild->spp != 1 ) {
-    if ( !NotMonoChrom(opt->f) && (bild->spp = IsMonochrome(bild)) == 1 ) {
-      bild->spp = 1;
-      Gray2Green(bild->DATA, bild->size);
+    if ( (buf = GetCharSpec(bild->spec, ChunkPhysicalDataFile)) ) {
+      LoadPhysicalParameters(buf);
     }
+#endif
+    if ( OnlyInfo(opt->f) ) continue;
+
+    if ( bild->spp != 1 ) {
+      if ( !NotMonoChrom(opt->f) && (bild->spp = IsMonochrome(bild)) == 1 ) {
+        bild->spp = 1;
+        if ( !DisplayGray(opt->f) ) Gray2Green(bild->DATA, bild->size);
+      }
+    }
+    if ( Shrink(opt->f) ) ShrinkPicture(bild, opt->shr);
   }
-  if ( Shrink(opt->f) ) ShrinkPicture(bild, opt->shr);
-  return bild;
+  return loadlist;
 }
 
-GList *ReadPicFiles(int nfiles, char **efiles, OPTIONS *opt)
+GList *ReadPicFiles(GList *piclist, int nfiles, char **efiles, OPTIONS *opt)
 /* Read a list of image files
  * --- Parameter: ---
  * int       nfiles      : number of filenames
@@ -491,11 +497,12 @@ GList *ReadPicFiles(int nfiles, char **efiles, OPTIONS *opt)
   PICTURE  *bild;
   char    **fp, **fip;
   int       i = 0;
-  GList    *piclist = NULL;
+  GList    *pl;
 
   for ( fip = (fp = efiles) + nfiles; fp < fip; fp++ ) {
-    if ( !(bild = ReadPic(*fp, opt)) ) continue;
-    piclist = g_list_append(piclist, bild);
+    if ( !(pl = ReadPic(*fp, opt)) ) continue;
+    for ( bild = BILD(pl); pl; bild = BILD(pl = pl->next) )
+      piclist = g_list_append(piclist, bild);
     if ( opt->cut && !SaveExtrema(opt->f ) ) {
       if ( DelBorder(opt->f) ) 
 	g_warning(_("No cutting (-c) of images if option -r (delete border) was given!"));
